@@ -1,4 +1,3 @@
-
 with_mock_dir("handle_http_errors", {
   test_that("httr2_http_400 error condition is raised", {
     expect_error(
@@ -22,9 +21,11 @@ with_mock_dir("handle_http_errors", {
 
   test_that("httr2_http_422 error condition is raised", {
     expect_error(get_genes("CRP", page = -1),
-                 class = "httr2_http_422")
+      class = "httr2_http_422"
+    )
 
     expect_error(get_genes("CRP", page = -1),
-                 regexp = "`page`: ensure this value is greater than or equal to 0")
+      regexp = "`page`: ensure this value is greater than or equal to 0"
+    )
   })
 })
